==> running_apps-0.0.3.tar.gz: android/src/main/java/com/DevAsh/running_apps/RunningAppsPlugin.java <==
package com.DevAsh.running_apps;

import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;
import io.flutter.plugin.common.PluginRegistry.Registrar;
import android.app.Activity;
import android.app.ActivityManager;
import android.app.ActivityManager.RunningAppProcessInfo;
import android.content.ComponentName;
import java.util.ArrayList;
import java.util.List;
import java.io.DataOutputStream;
import android.content.pm.PackageManager;
import android.content.pm.ApplicationInfo;

/** RunningAppsPlugin */
public class RunningAppsPlugin implements MethodCallHandler {
  /** Plugin registration. */
  
  Activity activity;
  RunningAppsPlugin(Activity activity){
         this.activity=activity;
  }
  public static void registerWith(Registrar registrar) {
    final MethodChannel channel = new MethodChannel(registrar.messenger(), "running_apps");
    channel.setMethodCallHandler(new RunningAppsPlugin(registrar.activity()));
  }
  private static boolean isSTOPPED(ApplicationInfo pkgInfo) {

    return ((pkgInfo.flags & ApplicationInfo.FLAG_STOPPED) != 0);
  }
  private static boolean isSYSTEM(ApplicationInfo pkgInfo) {

    return ((pkgInfo.flags & ApplicationInfo.FLAG_SYSTEM) != 0);
  }

  @Override
  public void onMethodCall(MethodCall call, Result result) {
    if (call.method.equals("getPlatformVersion")) {
      result.success("Android " + android.os.Build.VERSION.RELEASE);


    }else if(call.method.equals("GetRunningApps")){

      boolean systemapps=call.argument("systemapps");

      PackageManager pm = activity.getPackageManager();
      List<ApplicationInfo> packages = pm.getInstalledApplications(PackageManager.GET_META_DATA);

      List<String> apps = new ArrayList<String>();
      for (ApplicationInfo packageInfo : packages) {

        //system apps! get out
        if (!isSTOPPED(packageInfo) && (!isSYSTEM(packageInfo) || systemapps)) {

            apps.add(packageInfo.packageName);

        }
      }

      result.success(apps);

      

    }else {
      result.notImplemented();
    }
  }
}

==> running_apps-0.0.5.tar.gz: android/src/main/java/com/DevAsh/running_apps/RunningAppsPlugin.java <==
package com.DevAsh.running_apps;

import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;
import io.flutter.plugin.common.PluginRegistry.Registrar;
import android.app.Activity;
import android.app.ActivityManager;
import android.app.ActivityManager.RunningAppProcessInfo;
import android.content.ComponentName;
import java.util.ArrayList;
import java.util.List;
import java.io.DataOutputStream;
import android.content.pm.PackageManager;
import android.content.pm.ApplicationInfo;

/** RunningAppsPlugin */
public class RunningAppsPlugin implements MethodCallHandler {
  /** Plugin registration. */
  
  Activity activity;
  RunningAppsPlugin(Activity activity){
         this.activity=activity;
  }
  public static void registerWith(Registrar registrar) {
    final MethodChannel channel = new MethodChannel(registrar.messenger(), "running_apps");
    channel.setMethodCallHandler(new RunningAppsPlugin(registrar.activity()));
  }


  public boolean isSTOPPED(ApplicationInfo pkgInfo) {
    System.out.println(ApplicationInfo.FLAG_STOPPED);
    return ((pkgInfo.flags & ApplicationInfo.FLAG_STOPPED) != 0);
  }
  public boolean isSYSTEM(ApplicationInfo pkgInfo) {

    return ((pkgInfo.flags & ApplicationInfo.FLAG_SYSTEM) != 0);
  }

  

  @Override
  public void onMethodCall(MethodCall call, Result result) {
    if (call.method.equals("getPlatformVersion")) {
      result.success("Android " + android.os.Build.VERSION.RELEASE);


    }else if(call.method.equals("RunningApps")){

      boolean systemapps=call.argument("systemapps");

      PackageManager pm = activity.getPackageManager();
      List<ApplicationInfo> packages = pm.getInstalledApplications(PackageManager.GET_META_DATA);

      List<String> apps = new ArrayList<String>();
      for (ApplicationInfo packageInfo : packages) {

        //system apps! get out
        if (!isSTOPPED(packageInfo) && (!isSYSTEM(packageInfo) || systemapps)) {

            apps.add(packageInfo.packageName);

        }
      }

      result.success(apps);

    }else if(call.method.equals("CurrentApps")){

      ActivityManager actvityManager = (ActivityManager)activity.getSystemService(activity.ACTIVITY_SERVICE );

      List<ActivityManager.RunningTaskInfo> recentTasks = actvityManager.getRunningTasks(Integer.MAX_VALUE);

      List<String> apps = new ArrayList<String>();

      for (int i = 0; i < recentTasks.size(); i++) 
       {
             apps.add(recentTasks.get(i).baseActivity.toString());         
       }
       result.success(apps);
      
     
    }
    else {
      result.notImplemented();
    }
  }
}
